Developers
Companies
GET /companies
Returns all companies of current account.
{
"companies": [
{
"company": {
...
}
},
...
]
}
<companies>
<company>
...
</company>
...
</companies>
GET /companies/company_id
Returns a single company identified by its ID.
{
"company": {
...
}
}
<company>
...
</company>
POST /companies
Create a new company
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&company[name]=company_name' -X POST https://www.triggerapp.com/api/v1/companies
Parameters:
| Attribute | Required? | Type | Remarks |
|---|---|---|---|
| name | yes | string | name of the company |
| billable | no | boolean | defaults to true |
| status | no | string | can either be lead, open (default) or archive |
| address1 | no | string | |
| address2 | no | string | |
| city | no | string | |
| postcode | no | string | |
| state | no | string | |
| phone | no | string | |
| country | no | string | |
| currency_symbol | no | string | can either be $, £, ¥, €, R, R$, CHF |
| custom_currency_symbol | no | string | maximum of 3 characters |
| task_rate | no | decimal | defaults to the default account hourly rate |
Response:
Returns status code 200 on success and the json or xml of the current company.
Failed requests will return 400.
PUT /companies/company_id
Update an existing company
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&company[name]=company_name&company[state]=company_state&...' -X PUT https://www.triggerapp.com/api/v1/companies/company_id
Response:
Returns status code 200 on success and the json or xml of the current company.
Failed requests will return 400.
DELETE /companies/company_id
Destroy an existing company
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX' -X DELETE https://www.triggerapp.com/api/v1/companies/company_id
Response:
Returns status code 204 on success and no content. Failed requests will return 400.
Trigger is closing on 30 April 2027 and is no longer accepting new accounts. Existing customers can still sign in.